@@ -1,20 +1,21 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from acconeer.exptool import a121
 
 
 # Client is an object that is used to interact with the sensor.
-client = a121.Client(
+client = a121.Client.open(
     # ip_address="<ip address of host (like a RPi). E.g. 192.168.XXX.YYY>",
     # or
     # serial_port="<serial port of module. E.g. COM3 or /dev/ttyUSBx for Window/Linux>",
     # or
     # usb_device=True,
+    # or
+    # mock=True,
 )
 
 # Establishes a connection to the server running on the sensor.
-client.connect()
 
 # Once the client is connected, information about the server can be accessed.
 print("Server Info:")
@@ -41,4 +42,4 @@ for i in range(n):
     print(result)
 
 # When we are done, we should close the connection to the server.
-client.disconnect()
+client.close()
