@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 import acconeer.exptool as et
@@ -13,8 +13,7 @@ First session - Setup session without calibration
                 Sensor will calibrate during setup
 """
 
-client = a121.Client(**a121.get_client_args(args))
-client.connect()
+client = a121.Client.open(**a121.get_client_args(args))
 
 sensor_config = a121.SensorConfig()
 client.setup_session(sensor_config)
@@ -26,15 +25,14 @@ client.calibrations_provided will be equal to {1: False} since calibration was n
 """
 print(f"Setup without provided calibration {client.calibrations_provided}")
 
-client.disconnect()
+client.close()
 
 """
 Second session - Setup session with calibration
                  Sensor will reuse calibration and not calibrate during setup
 """
 
-client = a121.Client(**a121.get_client_args(args))
-client.connect()
+client = a121.Client.open(**a121.get_client_args(args))
 
 sensor_config = a121.SensorConfig()
 client.setup_session(sensor_config, calibrations)
@@ -44,4 +42,4 @@ client.calibrations_provided will be equal to {1: True} since calibration was pr
 """
 print(f"Setup with provided calibration {client.calibrations_provided}")
 
-client.disconnect()
+client.close()
