@@ -1,14 +1,13 @@
 # Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
-SDK_VERSION = "0.8.0"
+SDK_VERSION = "1.0.0"
 
 from ._cli import ExampleArgumentParser, get_client_args
 from ._core import (
     _H5PY_STR_DTYPE,
     PRF,
     Client,
-    ClientBase,
     ClientError,
     ClientInfo,
     H5Record,
@@ -16,6 +15,7 @@ from ._core import (
     IdleState,
     InMemoryRecord,
     Metadata,
+    MockInfo,
     PersistentRecord,
     Profile,
     Record,
@@ -25,11 +25,14 @@ from ._core import (
     SensorCalibration,
     SensorConfig,
     SensorInfo,
+    SerialInfo,
     ServerError,
     ServerInfo,
     SessionConfig,
+    SocketInfo,
     StackedResults,
     SubsweepConfig,
+    USBInfo,
     ValidationError,
     ValidationResult,
     ValidationWarning,
