@@ -221,8 +221,6 @@ class ProcessorBackendPluginBase(
         result = self.client.get_next()
         assert isinstance(result, a121.Result)  # TODO: fix
 
-        self._frame_count += 1
-
         if result.data_saturated:
             self.send_status_message(self._format_warning(DATA_SATURATED_MESSAGE))
 
@@ -233,6 +231,4 @@ class ProcessorBackendPluginBase(
             self.send_status_message(self._format_warning(FRAME_DELAYED_MESSAGE))
 
         processor_result = self._processor_instance.process(result)
-        self.callback(GeneralMessage(name="rate_stats", data=self.client._rate_stats))
-        self.callback(GeneralMessage(name="frame_count", data=self._frame_count))
         self.callback(GeneralMessage(name="plot", data=processor_result, recipient="plot_plugin"))
