@@ -30,14 +30,7 @@ SIGNAL_TEMPERATURE_MODEL_PARAMETER = {
     a121.Profile.PROFILE_5: 104.0,
 }
 # Largest measurable distance per PRF.
-MAX_MEASURABLE_DIST_M = {
-    a121.PRF.PRF_19_5_MHz: 3.1,
-    a121.PRF.PRF_15_6_MHz: 5.1,
-    a121.PRF.PRF_13_0_MHz: 7.0,
-    a121.PRF.PRF_8_7_MHz: 12.7,
-    a121.PRF.PRF_6_5_MHz: 18.5,
-    a121.PRF.PRF_5_2_MHz: 24.3,
-}
+MAX_MEASURABLE_DIST_M = {prf: prf.mmd for prf in set(a121.PRF)}
 # Slope and interception of linear noise temperature model.
 NOISE_TEMPERATURE_MODEL_PARAMETER = [-0.00275, 0.98536]
 
