@@ -1,5 +1,5 @@
 # Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
-from ._detector import Detector, DetectorConfig, DetectorResult
+from ._detector import Detector, DetectorConfig, DetectorMetadata, DetectorResult
 from ._processors import Processor, ProcessorConfig, ProcessorResult
