@@ -143,6 +143,21 @@ class DetectorConfig(AlgoConfigBase):
         return validation_results
 
 
+@attrs.frozen(kw_only=True)
+class DetectorMetadata:
+    start_m: float = attrs.field()
+    """Actual start point of measurement in meters"""
+
+    step_length_m: float = attrs.field()
+    """Actual step length between each data point of the measurement in meters"""
+
+    num_points: int = attrs.field()
+    """The number of data points in the measurement"""
+
+    profile: a121.Profile = attrs.field()
+    """Profile used for measurement"""
+
+
 @attrs.frozen(kw_only=True)
 class DetectorResult:
     intra_presence_score: float = attrs.field()
@@ -179,12 +194,13 @@ class Detector(Controller[DetectorConfig, DetectorResult]):
     def __init__(
         self,
         *,
-        client: a121.ClientBase,
+        client: a121.Client,
         sensor_id: int,
         detector_config: DetectorConfig,
     ) -> None:
         super().__init__(client=client, config=detector_config)
         self.sensor_id = sensor_id
+        self.detector_metadata: Optional[DetectorMetadata] = None
 
         self.started = False
 
@@ -239,6 +255,13 @@ class Detector(Controller[DetectorConfig, DetectorResult]):
 
         processor_config = self._get_processor_config(self.config)
 
+        self.detector_metadata = DetectorMetadata(
+            start_m=sensor_config.start_point * Processor.APPROX_BASE_STEP_LENGTH_M,
+            step_length_m=metadata.base_step_length_m * sensor_config.step_length,
+            num_points=sensor_config.num_points,
+            profile=sensor_config.profile,
+        )
+
         self.processor = Processor(
             sensor_config=sensor_config,
             metadata=metadata,
