@@ -37,7 +37,7 @@ from acconeer.exptool.app.new import (
     GridGroupBox,
     Message,
     MiscErrorView,
-    PidgetFactoryMapping,
+    PidgetGroupFactoryMapping,
     PluginFamily,
     PluginGeneration,
     PluginPresetBase,
@@ -174,10 +174,6 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
             raise RuntimeError
         result = self._ref_app_instance.get_next()
 
-        self._frame_count += 1
-
-        self.callback(GeneralMessage(name="rate_stats", data=self.client._rate_stats))
-        self.callback(GeneralMessage(name="frame_count", data=self._frame_count))
         self.callback(GeneralMessage(name="plot", data=result, recipient="plot_plugin"))
 
 
@@ -428,17 +424,9 @@ class ViewPlugin(DetectorViewPluginBase):
         self.stop_button.setToolTip("Stops the session.\n\nShortcut: Space")
         self.stop_button.clicked.connect(self._send_stop_request)
 
-        self.defaults_button = QPushButton(
-            qta.icon("mdi6.restore", color=BUTTON_ICON_COLOR),
-            "Reset settings and calibrations",
-            self.sticky_widget,
-        )
-        self.defaults_button.clicked.connect(self._send_defaults_request)
-
         button_group = GridGroupBox("Controls", parent=self.sticky_widget)
         button_group.layout().addWidget(self.start_button, 0, 0)
         button_group.layout().addWidget(self.stop_button, 0, 1)
-        button_group.layout().addWidget(self.defaults_button, 1, 0, 1, -1)
 
         sticky_layout.addWidget(button_group)
 
@@ -477,14 +465,16 @@ class ViewPlugin(DetectorViewPluginBase):
         self.scrolly_widget.setLayout(scrolly_layout)
 
     @classmethod
-    def _get_pidget_mapping(cls) -> PidgetFactoryMapping:
+    def _get_pidget_mapping(cls) -> PidgetGroupFactoryMapping:
         presence_pidget_mapping = dict(PresenceViewPlugin._get_pidget_mapping())
         presence_pidget_mapping.update(
             {
-                "num_zones": pidgets.IntPidgetFactory(
-                    name_label_text="Number of zones",
-                    limits=(1, None),
-                ),
+                pidgets.FlatPidgetGroup(): {
+                    "num_zones": pidgets.IntPidgetFactory(
+                        name_label_text="Number of zones",
+                        limits=(1, None),
+                    ),
+                }
             }
         )
         return presence_pidget_mapping
@@ -505,7 +495,6 @@ class ViewPlugin(DetectorViewPluginBase):
         if state is None:
             self.start_button.setEnabled(False)
             self.stop_button.setEnabled(False)
-            self.defaults_button.setEnabled(False)
 
             self.config_editor.set_data(None)
             self.config_editor.setEnabled(False)
@@ -515,8 +504,6 @@ class ViewPlugin(DetectorViewPluginBase):
 
         assert isinstance(state, SharedState)
 
-        self.defaults_button.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
-
         self.config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.config_editor.set_data(state.config)
         self.plot_config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
@@ -524,7 +511,9 @@ class ViewPlugin(DetectorViewPluginBase):
         self.sensor_id_pidget.set_selected_sensor(state.sensor_id, app_model.connected_sensors)
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
-        self.start_button.setEnabled(app_model.is_ready_for_session())
+        self.start_button.setEnabled(
+            app_model.is_ready_for_session() and self.config_editor.is_ready
+        )
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
     def _on_config_update(self, config: RefAppConfig) -> None:
