@@ -1,7 +1,8 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
-from ._backend import Backend, ClosedTask
+from ._application_client import ApplicationClient
+from ._backend import Backend, ClosedTask, Task
 from ._backend_logger import BackendLogger
 from ._backend_plugin import BackendPlugin
 from ._message import (
