@@ -14,6 +14,10 @@ def load_default_plugins() -> list[PluginSpec]:
     from acconeer.exptool.a121.algo.presence._detector_plugin import PRESENCE_DETECTOR_PLUGIN
     from acconeer.exptool.a121.algo.smart_presence._ref_app_plugin import SMART_PRESENCE_PLUGIN
     from acconeer.exptool.a121.algo.sparse_iq._plugin import SPARSE_IQ_PLUGIN
+    from acconeer.exptool.a121.algo.surface_velocity._example_app_plugin import (
+        SURFACE_VELOCITY_PLUGIN,
+    )
+    from acconeer.exptool.a121.algo.tank_level._plugin import TANK_LEVEL_PLUGIN
     from acconeer.exptool.a121.algo.touchless_button._plugin import TOUCHLESS_BUTTON_PLUGIN
     from acconeer.exptool.a121.algo.vibration._plugin import VIBRATION_PLUGIN
 
@@ -27,4 +31,6 @@ def load_default_plugins() -> list[PluginSpec]:
         BILATERATION_PLUGIN,
         BREATHING_PLUGIN,
         SMART_PRESENCE_PLUGIN,
+        TANK_LEVEL_PLUGIN,
+        SURFACE_VELOCITY_PLUGIN,
     ]
